% PersonalityGuis
% Toggle boxes to determine personality

% Once again Left, bottom, width, height
% Normalized units map the lower-left corner of the parent object to (0,0)
% and the upper-right corner to (1.0,1.0). In this case of defining the
% button group the parent (button group) is the figure


ht = uibuttongroup('visible','on','Units', 'normalized', ...
    'Title', 'Personality Type' ,...
    'pos',[0 .4 .4 .4]);
% Create three toggle buttons in the button group.
% Left, bottom, width, height


% In the case of these uicontrols the parent 
% is the uibuttongroup box
u0 = uicontrol('Style','Toggle','String','Introverted', ...
    'parent',ht, 'Units', 'normalized',...
    'pos',[.1 .7 .8 .2],'HandleVisibility','off');
% Controls access to object's handle. This property determines when an
% object's handle is visible in its parent's list of children. I.e. whether you can
% access the handle to this uicontrol from the handle to the buttongroup.
% When a handle is not visible in its parent's list of children, it is 
% not returned by functions that obtain handles by searching the object 
%hierarchy or querying handle properties. This includes get, findobj, gca, 
% gcf, gco, newplot, cla, clf, and close. 
%Handles that are hidden are still valid. If you know an object's handle, 
%you can set and get its properties, and pass it to any function that 
% operates on handles. The reason to hide it is to prevent accidentally
% messing with your uicontrol. On the whole this is not something to worry
% about unless you either can't get hold of the properties of the
% uicontrol, in which case set HandleVisibility to "on" or some later
% function is messing with your uicontrol, in which case turn it "off"

u1 = uicontrol('Style','Toggle','String','Extroverted', ...
    'parent',ht,'Units','normalized', ...
    'pos',[.1 .4 .8 .2],'HandleVisibility','off');

u2 = uicontrol('Style','Toggle','String','Weird','Units', 'normalized', ...
    'parent',ht,'pos',[.1 .1 .8 .2],'HandleVisibility','off', 'FontWeight', 'bold');


% Initialize some button group properties.
set(ht,'SelectedObject',[]);  
% No default selection, otherwise the first toggle to be defined will be
% the default

set(ht,'SelectionChangeFcn',@toggleresponse);
% of you hit any of the buttons in the butttongroup, call toggleresponse,
% a set of default arguments, source,eventdata, are included in that call


